from functools import wraps

from .log_config import logger

LOGGING = {
            "CRITICAL": logger.critical,
            "ERROR": logger.error,
            "WARNING": logger.warning,
            "INFO": logger.info,
            "DEBUG": logger.debug,
            }

def log(name=__name__, msg=None, level="INFO"):
    def decorator(func):
        @wraps(func)
        def decorated(*args, **kwargs):
            log_decor = LOGGING[level]
            log_decor('{}-{}-{}'.format(name, func.__name__, msg))
            res = func(*args, **kwargs)

            return res
        return decorated
    return decorator



import os
import logging


def get_log_path():
    log_path = os.path.join(
                os.path.dirname(
                   os.path.dirname(
                        os.path.abspath(__file__))), 'log')
    if not os.path.exists(log_path):
        os.mkdir(log_path)
    return log_path

LOG_PATH = get_log_path()

logger = logging.getLogger("client_log")

filename=os.path.join(LOG_PATH, "fb.log")
formatter = logging.Formatter('%(asctime)s %(levelname)s: %(message)s')

fh = logging.FileHandler(filename, encoding='utf-8')
fh.setLevel(logging.DEBUG)
fh.setFormatter(formatter)

logger.addHandler(fh)
logger.setLevel(logging.DEBUG)




from sqlalchemy import Column, Integer, String, ForeignKey

from .settings import session, Base


class User(Base):
    '''Пользователи чата'''
    __tablename__ = 'User'
    id = Column(Integer, primary_key=True)
    username = Column(String, unique=True)
    avatar = Column(String)

    def __init__(self, username):
        self.username = username

    def __repr__(self):
        return "<User ('%s')>" % self.username

    def save(self):
        session.add(self)
        try:
            session.commit()
        except:
            session.rollback()


class ContactList(Base):
    '''Контакт лист'''
    __tablename__ = 'ContactList'
    id = Column(Integer, primary_key=True)
    client_id = Column(Integer, ForeignKey('User.id'))
    contact_id = Column(String)

    def save(self):
        session.add(self)
        try:
            session.commit()
        except:
            session.rollback()


class MessageHistory(Base):
    '''История'''
    __tablename__ = 'MessageHistory'
    history_id = Column(Integer, primary_key=True)
    user_id = Column(Integer, ForeignKey('User.id'))
    message_to = Column(String)
    message_from = Column(String)



# класс пользовательского интерфеса

import sys
from PyQt5 import QtWidgets, QtGui

from pypi_client.accounts.account import UserManager
from pypi_client.core.handlers import GuiReciever
from pypi_client.protocol.jim import Messages
from pypi_client.utils.utils import get_path

from .ui_files.client_ui import Ui_MainWindow
from .dialogs import EnterDialog, HelpDialog, AboutDialog
from .acc_settings import AccSetiingsDialog


class UserGUI(QtWidgets.QMainWindow):
    '''Класс графического интерфейса'''
    messages = Messages()

    def __init__(self, socket, parent=None):
        super().__init__()
        # иницилизация клиента
        self.user = None
        self.socket = socket
        self.thread = None
        self.contacts = []
        # Иконки для контактов
        self.icon_contact = QtGui.QIcon()
        self.icon_contact.addPixmap(QtGui.QPixmap(get_path("yang.png")),
                                    QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.icon = QtGui.QIcon()
        self.icon.addPixmap(QtGui.QPixmap(get_path("icon.png")),
                                          QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.initUI()

    def initUI(self):
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)
        self.setWindowIcon(self.icon)
        self.center()
        self.start_chat()
        self.set_avatar()
        # MENU
        self.ui.actionExit.triggered.connect(self.quit)
        self.ui.actionAccSet.triggered.connect(self.acc_settings)
        self.ui.actionHelp.triggered.connect(self.get_help)
        self.ui.actionAbout.triggered.connect(self.about)
        # Buttons and chatContacts
        self.ui.addButton.clicked.connect(self.add_contact)
        self.ui.delButton.clicked.connect(self.del_contact)
        self.ui.sendButton.clicked.connect(self.send)
        self.ui.chatText.returnPressed.connect(self.send)
        self.ui.contactListWidget.itemDoubleClicked.connect(self.add_privat)

    def center(self):
        screen = QtWidgets.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width()-size.width())/2,
            (screen.height()-size.height())/2)

    def start_chat(self):
        ''' Вывод диалога входа, загрузка начальных параметров
            Контакт лист, имя и тд
        '''
        enter_dialog = EnterDialog(parent=self)
        enter = enter_dialog.exec()
        if enter == QtWidgets.QDialog.Accepted:
            data = enter_dialog.data
            self.user = data["user"]
            presence = self.messages.presence_msg(account_name=self.user.username)
            self.socket.send_msg(presence)
            data_msg = self.socket.get_msg()
            response = data_msg.get('alert', None)
            msg = """<p style="margin-top:0px; margin-bottom:0px;
                         margin-left:0px; margin-right:0px;
                        -qt-block-indent:0; text-indent:0px;">
                    <span style="color:red;">SERVER#</span>
                {}</p>""".format(response)
            self.ui.chatWindow.insertHtml(msg)
            self.ui.username.setText(self.user.username)
            contacts = data_msg.get('contacts', None)
            if contacts:
                self.contacts = contacts
            self.get_contacts()

    def acc_settings(self):
        '''Параметры аккаунта'''
        user_manager = UserManager()
        acc = AccSetiingsDialog(self.user, parent=self)
        dialog = acc.exec()
        if dialog == QtWidgets.QDialog.Accepted:
            user_manager.create_avatar(acc.fname['fname'], self.user)
            self.set_avatar()

    def set_avatar(self):
        '''Уставить аватар'''
        if self.user.avatar is None:
            self.ui.avatar.setPixmap(QtGui.QPixmap(get_path("icon.png")))
        else:
            self.ui.avatar.setPixmap(QtGui.QPixmap(self.user.avatar))

    def get_help(self):
        '''Выводит диалог с описанием чата'''
        hd = HelpDialog(parent=self)
        hd.exec()

    def about(self):
        '''Выводит диалог с описанием программы'''
        ab = AboutDialog(parent=self)
        ab.exec()

    def get_chat(self):
        '''Метод для вызова в потоке'''
        return self.ui.chatWindow

    def get_contacts(self):
        '''Получить контакты'''
        self.ui.contactListWidget.clear()
        for contact in self.contacts:
            item = QtWidgets.QListWidgetItem()
            item.setIcon(self.icon_contact)
            item.setText(contact)
            self.ui.contactListWidget.addItem(item)

    def add_contact(self):
        '''добавление контакта'''
        contact_name, ok = QtWidgets.QInputDialog.getText(self,
                                                          'Новый контакт',
                                                          'Имя(nickname):')
        if ok:
            add_contact = self.messages.edit_contact('add',
                                                     self.user.username,
                                                     contact_name)
            self.socket.send_msg(add_contact)
            self.contacts.append(contact_name)
            self.get_contacts()

    def del_contact(self):
        '''удаление контакта'''
        item = self.ui.contactListWidget.currentIndex()
        contact_name = item.data()
        del_contact = self.messages.edit_contact('del',
                                                 self.user.username,
                                                 contact_name)
        self.socket.send_msg(del_contact)
        self.contacts.remove(contact_name)
        self.get_contacts()

    def add_privat(self):
        '''по двойному клику устанавливает команду на приватное сообщение'''
        name = self.ui.contactListWidget.currentIndex().data()
        self.ui.chatText.setStyleSheet('color: purple')
        msg = self.ui.chatText.setText('/priv {}'.format(name))

    def send(self):
        '''Отправка сообщения!'''
        # Нужно переделать с broadcast на '#all'!!!!!!!!!!
        action = 'broadcast'
        to = '#all'
        name=self.user.username
        msg = self.ui.chatText.text()
        if msg.startswith('/priv'):
            action = 'msg'
            line = msg.split()
            to = line[1]
            msg = ' '.join(line[2:])
        message = self.messages.get_user_msg(action, msg, to=to, name=name)
        self.socket.send_msg(message)
        show_msg = """<p><span style="color:green;">Вы#</span>
                        {}</p>""".format(msg)
        self.ui.chatWindow.append(show_msg)
        self.ui.chatText.clear()
        self.ui.chatText.setStyleSheet('color: black')

    def quit(self):
        '''посылает сообщение серверу об отключение клиента и выходит'''
        message = self.messages.action(username=self.user.username)
        self.socket.send_msg(message)
        if self.thread:
            self.thread.exit()
        self.close()



import logging

from hashlib import md5

from PIL import Image

from pypi_client.utils import log_config
from pypi_client.utils.utils import get_path
from .db.settings import session, Base, engine
from .db.models import User, ContactList


logger = logging.getLogger("client_log")
# Создаю таблицы - думаю есть место получше куда вставить
Base.metadata.create_all(engine)


class UserManager():
    '''Менежер пользователей'''

    def create_user(self, username):
        user = User(username.strip())
        user.save()
        return user

    def create_avatar(self, fname, user):
        '''создание аватарки из ранее загруженного файла
            TODO - "мусорные файлы!!! Остается мусор в виде старых аватарок"
        '''
        size = 200, 180
        avatar = Image.open(fname)
        avatar.thumbnail(size)
        filename = md5(fname.encode()).hexdigest()[-7:]
        avatar_path = get_path(filename + ".png")
        # Сохраняю файл на диск
        avatar.save(avatar_path, "PNG")
        # сохраняю путь в БД
        user.avatar = avatar_path
        user.save()

    def get_user(self, username):
        user = session.query(User).filter(User.username==username).first()
        return user

    def get_users(self):
        users = session.query(User).all()
        return users

class ContactManager():
    '''Менеджер контактов пользователя'''
    def add_contact(self, user_id, contact):
        contact = ContactList()
        contact.user_id = user_id
        contact.username = contact
        contact.save()

    def get_contact_list(self, contacts):

        pass


import os

from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sqlalchemy.ext.declarative import declarative_base

DEBUG = False

db_name = os.path.join(
            os.path.dirname(
                os.path.abspath(__file__)), 'db_client.sqlite')

db_engine = 'sqlite:///{}'.format(db_name)

engine = create_engine(db_engine, echo=DEBUG)

Base = declarative_base()

Session = sessionmaker()
Session.configure(bind=engine)
session = Session()





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'acc_set.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(900, 350)
        Dialog.setMaximumSize(QtCore.QSize(900, 350))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(400, 270, 421, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.load_avatar = QtWidgets.QLabel(Dialog)
        self.load_avatar.setGeometry(QtCore.QRect(80, 40, 241, 241))
        self.load_avatar.setAutoFillBackground(False)
        self.load_avatar.setText("")
        self.load_avatar.setObjectName("load_avatar")
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setGeometry(QtCore.QRect(70, 20, 261, 16))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setGeometry(QtCore.QRect(80, 280, 251, 16))
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.line_3 = QtWidgets.QFrame(Dialog)
        self.line_3.setGeometry(QtCore.QRect(50, 40, 20, 241))
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.line_4 = QtWidgets.QFrame(Dialog)
        self.line_4.setGeometry(QtCore.QRect(330, 30, 20, 251))
        self.line_4.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.verticalLayoutWidget = QtWidgets.QWidget(Dialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(420, 140, 401, 101))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_4 = QtWidgets.QLabel(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.verticalLayout.addWidget(self.label_4)
        self.label_6 = QtWidgets.QLabel(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.verticalLayout.addWidget(self.label_6)
        self.label_7 = QtWidgets.QLabel(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.verticalLayout.addWidget(self.label_7)
        self.verticalLayoutWidget_2 = QtWidgets.QWidget(Dialog)
        self.verticalLayoutWidget_2.setGeometry(QtCore.QRect(420, 60, 410, 60))
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.verticalLayoutWidget_2)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.verticalLayoutWidget_2)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.addButton = QtWidgets.QPushButton(Dialog)
        self.addButton.setGeometry(QtCore.QRect(190, 300, 31, 27))
        self.addButton.setText("")
        self.addButton.setObjectName("addButton")

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label_4.setText(_translate("Dialog", "ВНИМАНИЕ! Аватарка будет "))
        self.label_6.setText(_translate("Dialog", "масштабирована под размеры"))
        self.label_7.setText(_translate("Dialog", "интерфейса"))
        self.label_2.setText(_translate("Dialog", "Нажмите на кнопку \"+\" и выберите файл "))
        self.label_3.setText(_translate("Dialog", "для загрузки аватарки."))




from string import Template
from PyQt5.QtCore import QObject, pyqtSignal


class Receiver:
    ''' Класс-получатель информации из сокета
    '''
    def __init__(self, sock):
        self.sock = sock
        self.is_alive = False

    def process_message(self, message):
        pass

    def server_message(self, message):
        pass

    def poll(self):
        self.is_alive = True
        while True:
            if not self.is_alive:
                break
            data = self.sock.get_msg()
            if data:
                try:
                    if data['action'] == 'msg'\
                         or data['action'] == 'broadcast':
                        self.process_message(data)
                    else:
                        # нужно очередь добалять!
                        pass
                except:
                    pass
            else:
                break

    def stop(self):
        self.is_alive = False

class GuiReciever(Receiver, QObject):
    gotData = pyqtSignal(str)
    finished = pyqtSignal(int)

    def __init__(self, sock):
        Receiver.__init__(self, sock)
        QObject.__init__(self)
        self.templates = {
            "to": Template("""<p><span style="color:purple;">
                                    PRIVATE $from#</span>
                                    $message</p>"""),
            "#all": Template("""<p><span style="color: #0048BA;">
                                        $from# </span>
                                        $message</p>"""),
        }

    def process_message(self, message):
        to = self.templates["#all"] \
                            if message["to"] == "#all" else self.templates["to"]
        self.gotData.emit(to.substitute(message))

    def poll(self):
        super().poll()
        self.finished.emit(0)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'help.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(555, 605)
        Dialog.setMaximumSize(QtCore.QSize(555, 605))
        self.pushButton = QtWidgets.QPushButton(Dialog)
        self.pushButton.setGeometry(QtCore.QRect(230, 550, 85, 27))
        self.pushButton.setObjectName("pushButton")
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(20, 10, 511, 41))
        font = QtGui.QFont()
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setGeometry(QtCore.QRect(10, 51, 531, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setGeometry(QtCore.QRect(10, 520, 531, 20))
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.textBrowser = QtWidgets.QTextBrowser(Dialog)
        self.textBrowser.setGeometry(QtCore.QRect(25, 81, 501, 441))
        self.textBrowser.setObjectName("textBrowser")

        self.retranslateUi(Dialog)
        self.pushButton.clicked.connect(Dialog.close)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.pushButton.setText(_translate("Dialog", "Закрыть"))
        self.label.setText(_translate("Dialog", "Помощь"))
        self.textBrowser.setHtml(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Noto Sans\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:14pt; font-weight:600;\">1.</span><span style=\" font-size:14pt;\"> Отправка сообщения - по умолчанию отправляет всем.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:14pt; font-weight:600;\">2.</span><span style=\" font-size:14pt;\"> При двойном клике или написании команды </span><span style=\" font-size:14pt; color:#aa00ff;\">/priv &lt;name&gt; СООБЩЕНИЕ</span><span style=\" font-size:14pt;\"> - отправляет сообщение &lt;name&gt;.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:14pt; font-weight:600;\">3.</span><span style=\" font-size:14pt;\"> </span><span style=\" font-size:14pt; color:#00aa00;\">Добавить</span><span style=\" font-size:14pt;\">/</span><span style=\" font-size:14pt; color:#ff0000;\">Удалить</span><span style=\" font-size:14pt;\"> контакты - удаляет добавляет контакты пользователя.</span></p></body></html>"))




import os
import sys
import argparse


def get_params():
    '''параметры запуска клиента'''
    params ={}

    parser = argparse.ArgumentParser(description="Параметры для чат клиента")
    group = parser.add_mutually_exclusive_group()
    group.add_argument("-ip", type=str, default="127.0.0.1",
                       help="Задать IP адресс сервера, по умолчанию 127.0.0.1")
    parser.add_argument("-port", type=int, default=7777,
                        help="Установить PORT сервера, по умолчанию 7777")
    args = parser.parse_args()
    params['ip'] = args.ip
    params['port'] = args.port
    return params


def get_path(icon):
    path = os.path.join(
                os.path.dirname(
                   os.path.dirname(
                        os.path.abspath(__file__))), 'ui/img')
    path_icon = "{}/{}".format(path, icon)
    return path_icon


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'client.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1010, 637)
        MainWindow.setMaximumSize(QtCore.QSize(1010, 637))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.chatWindow = QtWidgets.QTextEdit(self.centralwidget)
        self.chatWindow.setGeometry(QtCore.QRect(220, 50, 501, 501))
        self.chatWindow.setReadOnly(True)
        self.chatWindow.setObjectName("chatWindow")
        self.layoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget.setGeometry(QtCore.QRect(220, 560, 501, 41))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.chatText = QtWidgets.QLineEdit(self.layoutWidget)
        self.chatText.setObjectName("chatText")
        self.horizontalLayout.addWidget(self.chatText)
        self.sendButton = QtWidgets.QPushButton(self.layoutWidget)
        self.sendButton.setObjectName("sendButton")
        self.horizontalLayout.addWidget(self.sendButton)
        self.layoutWidget1 = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget1.setGeometry(QtCore.QRect(740, 560, 261, 41))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setSpacing(2)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.addButton = QtWidgets.QPushButton(self.layoutWidget1)
        self.addButton.setObjectName("addButton")
        self.horizontalLayout_3.addWidget(self.addButton)
        self.delButton = QtWidgets.QPushButton(self.layoutWidget1)
        self.delButton.setObjectName("delButton")
        self.horizontalLayout_3.addWidget(self.delButton)
        self.contactListWidget = QtWidgets.QListWidget(self.centralwidget)
        self.contactListWidget.setGeometry(QtCore.QRect(740, 50, 261, 501))
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.contactListWidget.setFont(font)
        self.contactListWidget.setObjectName("contactListWidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(740, 0, 181, 49))
        font = QtGui.QFont()
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(220, 0, 501, 49))
        font = QtGui.QFont()
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.username = QtWidgets.QLabel(self.centralwidget)
        self.username.setGeometry(QtCore.QRect(10, 250, 201, 35))
        self.username.setMaximumSize(QtCore.QSize(16777215, 35))
        font = QtGui.QFont()
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.username.setFont(font)
        self.username.setText("")
        self.username.setObjectName("username")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(10, 10, 56, 35))
        self.label_3.setMaximumSize(QtCore.QSize(56, 35))
        font = QtGui.QFont()
        font.setPointSize(22)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.line = QtWidgets.QFrame(self.centralwidget)
        self.line.setGeometry(QtCore.QRect(10, 40, 211, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.avatar = QtWidgets.QLabel(self.centralwidget)
        self.avatar.setGeometry(QtCore.QRect(10, 60, 200, 170))
        self.avatar.setMinimumSize(QtCore.QSize(200, 170))
        self.avatar.setMaximumSize(QtCore.QSize(200, 170))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.avatar.setFont(font)
        self.avatar.setText("")
        self.avatar.setAlignment(QtCore.Qt.AlignCenter)
        self.avatar.setObjectName("avatar")
        self.line_2 = QtWidgets.QFrame(self.centralwidget)
        self.line_2.setGeometry(QtCore.QRect(10, 280, 211, 20))
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.line_3 = QtWidgets.QFrame(self.centralwidget)
        self.line_3.setGeometry(QtCore.QRect(10, 230, 211, 20))
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menuBar = QtWidgets.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1010, 27))
        self.menuBar.setObjectName("menuBar")
        self.menu = QtWidgets.QMenu(self.menuBar)
        self.menu.setObjectName("menu")
        self.menu_2 = QtWidgets.QMenu(self.menuBar)
        self.menu_2.setObjectName("menu_2")
        self.menu_3 = QtWidgets.QMenu(self.menuBar)
        self.menu_3.setObjectName("menu_3")
        MainWindow.setMenuBar(self.menuBar)
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionHelp = QtWidgets.QAction(MainWindow)
        self.actionHelp.setObjectName("actionHelp")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionAccSet = QtWidgets.QAction(MainWindow)
        self.actionAccSet.setObjectName("actionAccSet")
        self.menu.addAction(self.actionExit)
        self.menu_2.addAction(self.actionHelp)
        self.menu_2.addAction(self.actionAbout)
        self.menu_3.addAction(self.actionAccSet)
        self.menuBar.addAction(self.menu.menuAction())
        self.menuBar.addAction(self.menu_3.menuAction())
        self.menuBar.addAction(self.menu_2.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Pypi Chat"))
        self.sendButton.setText(_translate("MainWindow", "Отправить"))
        self.addButton.setText(_translate("MainWindow", "Добавить"))
        self.delButton.setText(_translate("MainWindow", "Удалить"))
        self.label.setText(_translate("MainWindow", "Контакты:"))
        self.label_2.setText(_translate("MainWindow", "Чат:"))
        self.label_3.setText(_translate("MainWindow", "Вы:"))
        self.menu.setTitle(_translate("MainWindow", "Файл"))
        self.menu_2.setTitle(_translate("MainWindow", "Помощь"))
        self.menu_3.setTitle(_translate("MainWindow", "Настройки"))
        self.actionExit.setText(_translate("MainWindow", "Выход"))
        self.actionHelp.setText(_translate("MainWindow", "Помощь"))
        self.actionAbout.setText(_translate("MainWindow", "О программе"))
        self.actionAccSet.setText(_translate("MainWindow", "Аватар"))




#!/usr/bin/env python

# Клиент чата

import sys
import socket

from PyQt5 import QtWidgets
from PyQt5.QtCore import Qt, QThread, pyqtSlot

from pypi_client.core.client import Client
from pypi_client.core.handlers import GuiReciever
from pypi_client.utils.utils import get_params
from pypi_client.ui.gui_class import UserGUI


params = get_params()
app = QtWidgets.QApplication(sys.argv)
client = Client(**params)
userGUI = UserGUI(client)
window = userGUI.get_chat()


@pyqtSlot(str)
def update_chat(data):
    ''' Отображение сообщения в чате
    '''
    try:
        msg = data
        window.append(msg)
    except Exception as e:
        print(e)


def main():
    '''основная функция - для .whl'''
    reciever = GuiReciever(client)
    reciever.gotData.connect(update_chat)
    th = QThread()
    reciever.moveToThread(th)
    th.started.connect(reciever.poll)
    th.start()
    userGUI.thread = th
    userGUI.show()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()


import pytest
import sys
import socket


def get_user_msg(msg):
    ''' Получения сообщения от пользователя'''
    MESSAGE = {
        "action": "msg",
        "time": "timestamp",
        "to": "#all",
        "from": 'user',
        "message": msg,
    }
    return MESSAGE


def test_get_user_msg():
    msg = "test message"
    assert get_user_msg(msg) == {"action": "msg",
                                     "time": "timestamp",
                                     "to": "#all",
                                     "from": 'user',
                                     "message": msg,
                                     }



# Класссы реализации сообщений:
#    Message > JIM Сообщение​
#    Responce > JIM Ответ​

import json

from datetime import datetime


class Messages:
    '''Формирование сообщений по протоколу JIM'''
    time = datetime.now()

    def presence_msg(self, **kwargs):
        presence = {
            "action": "presence",
            "time":str(self.time),
            "type": "status",
            "user":{
                "account_name": kwargs.get('account_name',
                                           'Anonymous'),
                "status": "Yep, I am​ here!",
            }
        }
        return presence

    def get_user_msg(self, action, msg, **kwargs):
        ''' Получения сообщения от пользователя'''
        message = {
            "action": action,
            "time": str(self.time),
            "to": kwargs.get('to', '#all'),
            "from": kwargs.get('name', 'Anonymous'),
            "message": msg,
        }
        return message

    def action(self, **kwargs):
        '''Отправка простых действий:
           Покинуть комнату, по умолчанию выход'''
        action = {
            "action": kwargs.get("action", "quit"),
            "time": str(self.time),
            "from": kwargs.get("username", None),
            "room": kwargs.get("action", "main"),
        }
        return action

    def edit_contact(self, action, user, contact):
        ''' Получения сообщения от пользователя'''
        message = {
            "action": action,
            "time": str(self.time),
            "from": user,
            "contact": contact,
        }
        return message



from PyQt5 import QtWidgets, QtGui

from pypi_client.utils.utils import get_path

from .ui_files import acc_set_ui


class AccSetiingsDialog(QtWidgets.QDialog):
    '''Класс входа в чат'''
    def __init__(self, user, parent=None):
        super().__init__(parent)
        self.initUI()
        self.user = user
        self.fname = {}

    def initUI(self):
        self.ui = acc_set_ui.Ui_Dialog()
        self.ui.setupUi(self)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(get_path("add_icon.png")),
                                     QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.ui.addButton.setIcon(icon)
        self.ui.addButton.clicked.connect(self.add_avatar)

    def add_avatar(self):
        '''Создание аватарки'''
        fname = QtWidgets.QFileDialog.getOpenFileName(self,
                                                           'Open file',
                                                           '/home')[0]
        print(fname)

        pixmap = QtGui.QPixmap(fname)
        self.ui.load_avatar.setPixmap(pixmap)
        self.fname['fname'] = fname


from setuptools import setup, find_packages


setup(
    name="pypi-chat",
    version='0.0.4',
    description="A project of pypi chat.",
    long_description="A chat-client project on python 3 and PyQt5",
    author="Daniyar Kaliyev",
    author_email="danikspirit@gmail.com",
    url="https://github.com/dankaliyev/pypi_chat-cli",
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Communications :: Chat',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords=['PyQT5 chat client', 'chat PyQt 5', 'client jim chat'],
    packages=find_packages('src'),
    package_dir={'pypi_client': 'src/pypi_client'},
    package_data={'pypi_client':
                        ['ui/img/*.png',
                         'ui/img/*.jpg',
                         'ui/img/*.gif']
    },
    install_requires=[
        "Pillow==4.3.0",
        "PyQt5==5.9",
        "SQLAlchemy==1.1.14",
    ],
    extras_require={
        'dev': ['flake8==3.4.1'],
        'test': ["pytest==3.2.2",
                 "pytest-cov==2.5.1",
                 "pytest-sugar==0.9.0",
                 "PyYAML==3.12"],
    },
    entry_points={
        'gui_scripts': [
            'pypi-chat= pypi_client.main:main',
        ],
    },
)


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'enter.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(421, 217)
        self.verticalLayoutWidget = QtWidgets.QWidget(Dialog)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(20, 20, 391, 167))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.comboBox = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox.setObjectName("comboBox")
        self.verticalLayout.addWidget(self.comboBox)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButton_3 = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout.addWidget(self.pushButton_3)
        self.pushButton_2 = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout.addWidget(self.pushButton_2)
        self.pushButton = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "Выберите пользователя:"))
        self.pushButton_3.setText(_translate("Dialog", "Вход"))
        self.pushButton_2.setText(_translate("Dialog", "Выйти"))
        self.pushButton.setText(_translate("Dialog", "Регистрация"))




import sys
import json
import logging
import socket

from pypi_client.utils import log_config


logger = logging.getLogger("client_log")


class Client():
    '''Клиент Pypi Chat'''
    def __init__(self, **params):
        self.ip = params.get('ip', '127.0.0.1')
        self.port = params.get('port', 7777)
        self.conection = self.connect()

    def connect(self):
        '''Подключение к серверу'''
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        try:
            sock.connect((self.ip, self.port))
        except ConnectionRefusedError:
            print("Сервер недоступен!")
            sys.exit(0)
        return sock

    def send_msg(self, msg):
        '''Отправка сообщения серверу'''
        msg_str = json.dumps(msg)
        self.conection.sendall(msg_str.encode('utf-8'))

    def get_msg(self):
        '''Ответ сервера и преобразоание в словарь'''
        msg = self.conection.recv(1024)
        msg = msg.decode("utf-8")
        try:
            msg = json.loads(msg)
        except json.decoder.JSONDecodeError as error:
            logger.warning('Ошибка данных: {}'.format(error))
            msg = {'alert': 'Ошибка'}
        return msg

    def get_msg_server(self, msg):
        '''Ответ сервера и преобразоание в словарь'''
        try:
            msg = json.loads(msg)
        except json.decoder.JSONDecodeError as error:
            logger.warning('Ошибка данных: {}'.format(error))
            msg = {'alert': 'Ошибка'}
        return msg



import sys
from PyQt5 import QtWidgets, QtGui

from pypi_client.accounts.account import UserManager
from pypi_client.utils.utils import get_path

from .ui_files import enter_ui, help_ui, about_ui


class EnterDialog(QtWidgets.QDialog):
    '''Класс входа в чат'''
    def __init__(self, parent=None):
        super().__init__(parent)
        self.user = UserManager
        self.data = {}
        self.initUI()
        self.all_users = self.get_names()
        self.ui.comboBox.addItems(self.all_users)

    def initUI(self):
        self.ui = enter_ui.Ui_Dialog()
        self.ui.setupUi(self)
        self.ui.pushButton.clicked.connect(self.register_btn)
        self.ui.pushButton_3.clicked.connect(self.enter_chat)
        self.ui.pushButton_2.clicked.connect(sys.exit)

    def get_names(self):
        '''Имена из БД'''
        users = self.user()
        users = users.get_users()
        all_users = [user.username for user in users]
        return all_users

    def register_btn(self):
        '''регистрация пользователя
            todo - проверка на существование!!!
        '''
        name, ok = QtWidgets.QInputDialog.getText(self, 'Новый пользователь', 'Имя(nickname):')
        if ok:
            # ничего уменее не пришло в голову((
            if len(name.split()) > 1:
                name = ''.join(name.split())
            user = self.user()
            username = user.create_user(name)
            self.all_users.append(username.username)
            self.ui.comboBox.clear()
            self.ui.comboBox.addItems(self.all_users)

    def enter_chat(self):
        user = self.user()
        user_obj = user.get_user(self.ui.comboBox.currentText())
        self.data["user"] = user_obj
        self.accept()


class HelpDialog(QtWidgets.QDialog):
    '''Помощь в чате'''
    def __init__(self, parent=None):
        super().__init__(parent)
        self.initUI()

    def initUI(self):
        self.ui = help_ui.Ui_Dialog()
        self.ui.setupUi(self)


class AboutDialog(QtWidgets.QDialog):
    '''О программе'''
    def __init__(self, parent=None):
        super().__init__(parent)
        self.initUI()

    def initUI(self):
        self.ui = about_ui.Ui_Dialog()
        self.ui.setupUi(self)
        self.ui.label_3.setPixmap(QtGui.QPixmap(get_path("icon.png")))
